
from axdscfg.axdscfg import main

__all__ = [
    "__title__", "__summary__", "__version__", "__author__",
    "__email__", "__license__",
]

__title__ = "axdscfg"
__summary__ = ("Python lib to get credentials from encrypted file.")

__version__ = "1.0.0"

__author__ = "Axiomas Data Science"
__email__ = "suporte@axiomas.tech"

__license__ = "GNU GENERAL PUBLIC LICENSE 3"
